# noqa: D100

__title__ = "rics"
__description__ = "My personal little ML engineering library."
__version__ = "0.15.0"
__author__ = "Richard Sundqvist"
__copyright__ = "2022, Richard Sundqvist"
